import { Suspense } from "react";

import { discourseCallbackVerify } from "@/lib/discourse/verify";
import { findAuthorization } from "@/lib/dto/authorization";
import { getClientByClientId } from "@/lib/dto/client";
import { getAuthorizeUrl } from "@/lib/oauth/authorize-url";
import { CallbackHandler } from "@/components/auth/callback-handler";

export interface DiscourseCallbackParams extends Record<string, string> {
  sig: string;
  sso: string;
  oauth: string;
}

export default async function DiscourseCallbackPage({
  searchParams,
}: {
  searchParams: DiscourseCallbackParams;
}) {
  const oauthParams = new URLSearchParams(atob(searchParams.oauth));
  // check client info
  const client = await getClientByClientId(
    oauthParams.get("client_id") as string,
  );
  if (!client) {
    throw new Error("Client Id invalid (code: -1004).");
  }

  // verify discourse callback
  const user = await discourseCallbackVerify(
    searchParams.sso,
    searchParams.sig,
  );

  // check authorization
  const authorization = await findAuthorization(user.id, client.id);
  let redirectUrl: string | undefined;

  if (authorization) {
    redirectUrl = await getAuthorizeUrl(oauthParams);
  }

  return (
    <main className="flex min-h-screen flex-col items-center justify-center">
      <div className="flex items-center justify-center">
        <Suspense>
          <CallbackHandler
            client={client}
            user={user}
            oauthParams={searchParams.oauth}
            hasAuthorization={!!authorization}
            redirectUrl={redirectUrl}
          />
        </Suspense>
      </div>
    </main>
  );
}
