import { NextResponse } from "next/server";

import { prisma } from "@/lib/prisma";
import { getCurrentUser } from "@/lib/session";

export async function POST(
  req: Request,
  { params }: { params: { id: string } },
) {
  try {
    const user = await getCurrentUser();
    if (!user || user.role !== "ADMIN") {
      return new NextResponse("Unauthorized", { status: 401 });
    }

    const { enabled } = await req.json();

    const client = await prisma.client.update({
      where: { id: params.id },
      data: { enabled },
    });

    // 如果禁用应用，同时禁用所有授权
    if (!enabled) {
      await prisma.authorization.updateMany({
        where: { clientId: params.id },
        data: { enabled: false },
      });
    }

    return NextResponse.json(client);
  } catch (error) {
    console.error("[CLIENT_STATUS_UPDATE]", error);
    return new NextResponse("Internal Error", { status: 500 });
  }
}
