import { UserRole } from "@prisma/client";
import type { NextAuthConfig } from "next-auth";
import Credentials from "next-auth/providers/credentials";

import { discourseCallbackVerify } from "./lib/discourse/verify";

// Notice this is only an object, not a full Auth.js instance
export default {
  providers: [
    Credentials({
      credentials: {
        id: { type: "text" },
        username: { type: "text" },
        email: { type: "text" },
        name: { type: "text" },
        avatarUrl: { type: "text" },
        role: { type: "text" },
        moderator: { type: "text" },
        groups: { type: "text" },
        sso: { type: "text" },
        sig: { type: "text" },
      },
      async authorize(credentials) {
        if (!credentials) return null;

        // 如果是 SSO 登录
        if (credentials.sso && credentials.sig) {
          return await discourseCallbackVerify(
            credentials.sso as string,
            credentials.sig as string,
          );
        }

        // 如果是直接传入用户数据
        if (credentials.id && credentials.username && credentials.email) {
          return {
            id: credentials.id as string,
            username: credentials.username as string,
            email: credentials.email as string,
            name: (credentials.name as string) || null,
            avatarUrl: (credentials.avatarUrl as string) || null,
            role: ((credentials.role as string) || "USER") as UserRole,
            moderator: credentials.moderator === "true",
            groups: credentials.groups
              ? JSON.parse(credentials.groups as string)
              : [],
            createdAt: new Date(),
            updatedAt: new Date(),
          };
        }

        return null;
      },
    }),
  ],
} satisfies NextAuthConfig;
