"use client";

import { useEffect, useState } from "react";
import { useRouter } from "next/navigation";
import { signIn } from "@/auth";
import { Client } from "@prisma/client";

import { AuthorizationCard } from "./authorization-card";

interface CallbackHandlerProps {
  client: Client;
  user: any;
  oauthParams: string;
  hasAuthorization: boolean;
  redirectUrl?: string;
}

export function CallbackHandler({
  client,
  user,
  oauthParams,
  hasAuthorization,
  redirectUrl,
}: CallbackHandlerProps) {
  const router = useRouter();
  const [error, setError] = useState<string | null>(null);
  const [isProcessing, setIsProcessing] = useState(true);

  useEffect(() => {
    async function handleAuth() {
      try {
        // 设置用户会话
        await signIn("credentials", {
          id: user.id,
          username: user.username,
          email: user.email,
          name: user.name,
          avatarUrl: user.avatarUrl,
          role: user.role,
          moderator: user.moderator,
          groups: JSON.stringify(user.groups),
          redirect: false,
        });

        // 如果已经授权过，直接重定向
        if (hasAuthorization && redirectUrl) {
          router.push(redirectUrl);
          return;
        }

        setIsProcessing(false);
      } catch (error) {
        console.error("Auth error:", error);
        setError("认证过程中发生错误");
        setIsProcessing(false);
      }
    }

    handleAuth();
  }, []);

  if (error) {
    return <div className="text-red-500">{error}</div>;
  }

  if (isProcessing) {
    return (
      <div className="flex items-center justify-center">
        <div className="h-8 w-8 animate-spin rounded-full border-4 border-primary border-t-transparent"></div>
        <span className="ml-2">处理中...</span>
      </div>
    );
  }

  return <AuthorizationCard client={client} oauthParams={oauthParams} />;
}
