"use client";

import { useCallback, useEffect, useState } from "react";
import { signIn } from "@/actions/user-authorize";

import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card";

interface UserAuthorizeProps extends React.HTMLAttributes<HTMLDivElement> {
  data: Record<string, any>;
}

export function UserAuthorize({
  className,
  data,
  ...props
}: UserAuthorizeProps) {
  const [isLoading, setIsLoading] = useState<boolean>(false);
  const [error, setError] = useState<Error | unknown>(null);

  const signInCallback = useCallback(async () => {
    if (isLoading) {
      return;
    }
    setIsLoading(true);
    try {
      await signIn({ ...data, redirectTo: "/dashboard" });
      setIsLoading(false);
    } catch (error) {
      setError(error);
      setIsLoading(false);
    }
  }, []);

  useEffect(() => {
    const timer = setTimeout(signInCallback, 5);
    return () => {
      clearTimeout(timer);
    };
  }, []);

  return (
    <>
      {error ? (
        <Card className="w-full">
          <CardHeader className="space-y-4 text-center">
            <div className="mx-auto flex h-16 w-16 items-center justify-center rounded-full bg-red-100">
              <div className="h-8 w-8 text-red-600">❌</div>
            </div>
            <CardTitle className="text-2xl font-semibold text-red-600">
              授权失败
            </CardTitle>
          </CardHeader>
          <CardContent>
            <p className="text-center text-gray-500">登录异常，授权失败！</p>
          </CardContent>
        </Card>
      ) : (
        <Card className="w-full">
          <CardHeader className="space-y-4 text-center">
            <div className="mx-auto flex h-16 w-16 items-center justify-center rounded-full bg-blue-100">
              <div className="h-8 w-8 animate-spin rounded-full border-4 border-blue-600 border-t-transparent"></div>
            </div>
            <CardTitle className="text-2xl font-semibold">
              正在处理授权
            </CardTitle>
          </CardHeader>
          <CardContent>账号信息验证中，准备跳转中，请稍等...</CardContent>
        </Card>
      )}
    </>
  );
}
