"use client";

import { useState } from "react";
import { Check, Copy } from "lucide-react";

import { cn } from "@/lib/utils";

function CopyButton({ text }: { text: string }) {
  const [copied, setCopied] = useState(false);

  const copy = () => {
    navigator.clipboard.writeText(text);
    setCopied(true);
    setTimeout(() => setCopied(false), 2000);
  };

  return (
    <button
      onClick={copy}
      className="absolute right-2 top-2 rounded-md p-2 transition-colors hover:bg-gray-100 dark:hover:bg-gray-800"
    >
      {copied ? (
        <Check className="h-4 w-4 text-green-500" />
      ) : (
        <Copy className="h-4 w-4 text-gray-500" />
      )}
    </button>
  );
}

export function CodeBlock({
  children,
  className,
}: {
  children: string;
  className?: string;
}) {
  return (
    <div className={cn("relative", className)}>
      <pre className="overflow-x-auto rounded-lg bg-gray-100 p-4 dark:bg-gray-800 sm:text-sm">
        <code className="text-sm">{children}</code>
      </pre>
      <CopyButton text={children} />
    </div>
  );
}
